"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CollapsibleHeaderLayout = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const header_1 = require("../header");
const useHeaderDimensions_1 = require("../hooks/useHeaderDimensions");
/**
 * [CollapsibleHeaderLayout](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--collapsible-header-layout) component
 *
 * This component displays a scrollable page with a header that shrinks between an expanded size and
 * a collapsed size as the page is scrolled. It uses a standard [`Header`](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--header)
 * and `ScrollView` component under the hood and
 * you can set all of the props directly to these components in order to configure them. The layout itself
 * is primarily responsible for tracking the current scroll position and updating the size of the `Header`.
 */
exports.CollapsibleHeaderLayout = (props) => {
    const { HeaderProps = { styles: {} }, theme: themeOverride, ScrollViewProps = {}, styles = {}, style, ...viewProps } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const scrollRef = react_1.useRef(null);
    const { getScaledHeight } = useHeaderDimensions_1.useHeaderDimensions();
    const animatedScrollValue = react_1.useRef(new react_native_1.Animated.Value(0)).current;
    const [scrollValue, setScrollValue] = react_1.useState(0);
    const headerVariant = HeaderProps.variant || 'dynamic';
    const startExpanded = HeaderProps.startExpanded || false;
    const collapsedHeight = getScaledHeight(HeaderProps.collapsedHeight || 56);
    const expandedHeight = getScaledHeight(HeaderProps.expandedHeight || 200);
    const scrollableDistance = expandedHeight - collapsedHeight;
    const initialScrollPosition = headerVariant === 'static' ? 0 : !startExpanded ? scrollableDistance : 0;
    // State Variables
    const [contentPadding] = react_1.useState(new react_native_1.Animated.Value(headerVariant === 'dynamic' || startExpanded || false ? expandedHeight : collapsedHeight));
    const [contentPaddingValue, setContentPaddingValue] = react_1.useState(headerVariant === 'dynamic' || startExpanded || false ? expandedHeight : collapsedHeight);
    // Animation function to smoothly animate the paddingTop of ScrollView
    const animatePadding = (padding) => react_native_1.Animated.timing(contentPadding, {
        toValue: padding,
        duration: header_1.ANIMATION_LENGTH,
        useNativeDriver: false,
    });
    // Track the scroll position here too so we can minimize unnecessary updates
    const onScrollChange = react_1.useCallback(({ value: scrollDistance }) => {
        // save the current value of the animated scroll position
        setScrollValue(scrollDistance);
    }, []);
    // Track the padding current (non animated) value so we can minimize unnecessary updates
    const onPaddingChange = react_1.useCallback(({ value: newPadding }) => {
        // save the current value of the animated padding
        setContentPaddingValue(newPadding);
    }, []);
    // Set up listeners
    react_1.useEffect(() => {
        const scroll = animatedScrollValue.addListener(onScrollChange);
        const padding = contentPadding.addListener(onPaddingChange);
        return () => {
            animatedScrollValue.removeListener(scroll);
            contentPadding.removeListener(padding);
        };
    }, [onScrollChange, onPaddingChange]);
    // Update the ScrollView padding and scroll position
    const updateScrollView = (data) => {
        const { padding, animate, scrollTo } = data;
        if (padding !== null && padding !== contentPaddingValue) {
            if (animate)
                animatePadding(padding).start();
            else
                contentPadding.setValue(padding);
        }
        // Only update the scroll position if it is not null and is different from the current
        if (scrollRef && scrollRef.current && scrollTo !== null && scrollTo !== scrollValue) {
            // @ts-ignore scrollRef can't be null here, but TS complains anyway
            scrollRef.current.scrollTo({
                x: 0,
                y: scrollTo,
                animated: animate,
            });
        }
    };
    return (react_1.default.createElement(react_native_1.View, Object.assign({}, viewProps, { style: [{ flex: 1, backgroundColor: theme.colors.background }, styles.root, style] }),
        react_1.default.createElement(header_1.Header, Object.assign({ testID: 'blui-header' }, HeaderProps, { updateScrollView: updateScrollView, scrollPosition: animatedScrollValue, style: [
                HeaderProps.styles ? HeaderProps.styles.root : {},
                HeaderProps.style,
                { position: 'absolute', zIndex: 100 },
            ] })),
        react_1.default.createElement(react_native_1.ScrollView, Object.assign({ testID: 'blui-scrollview', scrollEventThrottle: 32 }, ScrollViewProps, { ref: scrollRef, contentOffset: { x: 0, y: initialScrollPosition }, 
            // Bind the scroll position directly to our animated value
            onScroll: react_native_1.Animated.event([
                {
                    nativeEvent: {
                        contentOffset: {
                            y: animatedScrollValue,
                        },
                    },
                },
            ], {
                // User-supplied callback function
                listener: ScrollViewProps.onScroll,
                useNativeDriver: false,
            }) }),
            react_1.default.createElement(react_native_1.Animated.View, { testID: 'blui-padded-view', style: { paddingTop: contentPadding } }, props.children))));
};
