"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findChildByType = exports.inheritSharedProps = exports.mergeStyleProp = void 0;
const react_1 = __importDefault(require("react"));
/**
 * mergeStyleProp function
 *
 * This function takes a parent value and a child value as arguments. It returns the child value if it is
 * defined, otherwise it returns the parent value.
 *
 * @param parentValue The value of the property on the parent
 * @param childValue The value of the property on the child
 * @returns The child value if it is defined, otherwise the parent value
 */
exports.mergeStyleProp = (parentValue, childValue) => childValue !== undefined ? childValue : parentValue;
/**
 * inheritSharedProps function
 *
 * This function will take the properties object for a parent and a child and return an object
 * that represents the properly inherited props for the child. If a property is specified for the
 * child, that value will be used. If the value is undefined, it will use the value of the property
 * from the parent.
 *
 * @param parent object representation of the props of the parent element
 * @param child object representation of the props of the child element
 * @returns an object representing the child props with any undefined properties replaced by the parent values.
 */
exports.inheritSharedProps = (parent, child) => ({
    activeItemBackgroundColor: exports.mergeStyleProp(parent.activeItemBackgroundColor, child.activeItemBackgroundColor),
    activeItemBackgroundShape: exports.mergeStyleProp(parent.activeItemBackgroundShape, child.activeItemBackgroundShape),
    activeItemFontColor: exports.mergeStyleProp(parent.activeItemFontColor, child.activeItemFontColor),
    activeItemIconColor: exports.mergeStyleProp(parent.activeItemIconColor, child.activeItemIconColor),
    backgroundColor: exports.mergeStyleProp(parent.backgroundColor, child.backgroundColor),
    chevron: exports.mergeStyleProp(parent.chevron, child.chevron),
    collapseIcon: exports.mergeStyleProp(parent.collapseIcon, child.collapseIcon),
    disableActiveItemParentStyles: exports.mergeStyleProp(parent.disableActiveItemParentStyles, child.disableActiveItemParentStyles),
    divider: exports.mergeStyleProp(parent.divider, child.divider),
    expandIcon: exports.mergeStyleProp(parent.expandIcon, child.expandIcon),
    hidePadding: exports.mergeStyleProp(parent.hidePadding, child.hidePadding),
    itemFontColor: exports.mergeStyleProp(parent.itemFontColor, child.itemFontColor),
    itemIconColor: exports.mergeStyleProp(parent.itemIconColor, child.itemIconColor),
    nestedBackgroundColor: exports.mergeStyleProp(parent.nestedBackgroundColor, child.nestedBackgroundColor),
    nestedDivider: exports.mergeStyleProp(parent.nestedDivider, child.nestedDivider),
    theme: Object.assign({}, parent.theme, child.theme),
});
/**
 * findChildByType function
 *
 * This function searches the `children` array of a component and returns an array of child elements
 * whose displayName is included in the supplied list.
 *
 * @param children the children property of a react component
 * @param type an array of displayName values to search for
 * @returns an array of child elements whose displayName is in the search array
 */
exports.findChildByType = (children, type) => react_1.default.Children.map(children, (child) => {
    if (child && child.type) {
        const name = child.type.displayName;
        if (name && type.includes(name)) {
            return child;
        }
    }
}) || [];
