"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderActionItems = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const headerIcon_1 = require("./headerIcon");
const SearchContextProvider_1 = require("./contexts/SearchContextProvider");
const ClearIcon = { name: 'clear' };
const SearchIcon = { name: 'search' };
const makeStyles = () => {
    const fontScale = react_native_1.PixelRatio.getFontScale();
    return react_native_1.StyleSheet.create({
        root: {
            flexDirection: 'row',
            alignItems: 'center',
            position: 'absolute',
            right: 8,
            height: 56 * fontScale,
        },
        actionItem: {
            height: 40 * fontScale,
            width: 24 * fontScale + 16,
            paddingVertical: 8 * fontScale,
            paddingHorizontal: 8,
        },
        component: {
            height: 40 * fontScale,
            width: 40 * fontScale,
            justifyContent: 'center',
        },
    });
};
/**
 * HeaderActionItems component
 *
 * The HeaderActionItems is a helper component for organizing the contents in the Header. It is
 * used for displaying all of the action item icons and components.
 */
exports.HeaderActionItems = (props) => {
    const { actionItems, styles = {} } = props;
    const { searchConfig, searching, query, onClear, onSearch } = SearchContextProvider_1.useSearch();
    const defaultStyles = makeStyles();
    let items = actionItems || [];
    if (searching) {
        if (query) {
            items = [
                {
                    icon: ClearIcon,
                    onPress: onClear,
                },
            ];
        }
        else {
            items = [];
        }
    }
    else if (searchConfig) {
        items = [
            {
                icon: SearchIcon,
                onPress: onSearch,
            },
        ];
        if (actionItems) {
            items = items.concat(actionItems);
        }
    }
    if (items) {
        return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.root, styles.root] }, items.map((actionItem, index) => {
            if ('component' in actionItem) {
                return (react_1.default.createElement(react_native_1.View, { key: `action_${index}`, testID: `header-action-item${index}`, style: [
                        defaultStyles.component,
                        actionItem.width ? { width: actionItem.width } : {},
                        styles.component,
                    ] }, actionItem.component));
            }
            return (react_1.default.createElement(react_native_1.TouchableOpacity, { key: `action_${index}`, testID: `header-action-item${index}`, onPress: actionItem.onPress, style: [defaultStyles.actionItem, styles.actionItem] },
                react_1.default.createElement(headerIcon_1.HeaderIcon, { icon: actionItem.icon })));
        })));
    }
    return null;
};
