import React from 'react';
import { StyleProp, ViewStyle, ViewProps, TextStyle } from 'react-native';
import { ChannelValueProps as ChannelValuePropsType } from '../channel-value';
import { $DeepPartial } from '@callstack/react-theme-provider';
import { IconSource } from '../__types__';
export declare type HeroProps = ViewProps & {
    /** The text shown below the ChannelValue */
    label: string;
    /** A component to render for the primary icon  */
    icon?: IconSource;
    /**
     * The size of the primary icon (10-48)
     *
     * Default: 36
     */
    iconSize?: number;
    /**
     * The color of the primary icon
     *
     * Default: Theme.colors.text
     */
    iconColor?: string;
    /**
     * The color to use behind the primary icon
     *
     * Default: Theme.colors.surface
     */
    iconBackgroundColor?: string;
    /**
     * Props to be passed through to ChannelValue child component
     */
    ChannelValueProps?: ChannelValuePropsType;
    /** A callback function to execute when the Hero is pressed  */
    onPress?: () => void;
    /** Style overrides for internal elements. The styles you provide will be combined with the default styles. */
    styles?: {
        root?: StyleProp<ViewStyle>;
        iconWrapper?: StyleProp<ViewStyle>;
        values?: StyleProp<ViewStyle>;
        label?: StyleProp<TextStyle>;
    };
    /**
     * Theme value overrides specific to this component.
     */
    theme?: $DeepPartial<ReactNativePaper.Theme>;
};
/**
 * [Hero](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--hero) component
 *
 * The Hero is used to call attention to particular values of importance to the user. It includes a
 * large icon with a label and (typically) a [ChannelValue](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--channel-value) item. The channel value can be configured
 * through the `ChannelValueProps`, or passed declaratively as a child.
 */
export declare const Hero: React.FC<HeroProps>;
