"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListItemTag = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const color_1 = __importDefault(require("color"));
const colors_1 = require("@brightlayer-ui/colors");
const typography_1 = require("../typography");
const shared_1 = require("../utility/shared");
const listItemTagStyles = (props, theme, fontScale) => react_native_1.StyleSheet.create({
    root: {
        backgroundColor: props.backgroundColor || shared_1.getPrimary500(theme) || theme.colors.primary,
        color: props.fontColor ||
            (color_1.default(props.backgroundColor || shared_1.getPrimary500(theme) || theme.colors.primary).isLight()
                ? theme.dark
                    ? colors_1.black[500]
                    : theme.colors.textPalette?.primary || theme.colors.text
                : colors_1.white[50]),
        height: 16 * fontScale,
        padding: 0,
        paddingLeft: 4 * fontScale,
        paddingRight: 3 * fontScale,
        borderRadius: 2 * fontScale,
        fontFamily: theme.fonts.bold ? theme.fonts.bold.fontFamily : theme.fonts.medium.fontFamily,
        fontWeight: theme.fonts.bold ? theme.fonts.bold.fontWeight : theme.fonts.medium.fontWeight,
        overflow: 'hidden',
        lineHeight: 16,
        fontSize: 10,
        letterSpacing: 1,
    },
});
/**
 * [ListItemTag](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--list-item-tag) component
 *
 * This component is primarily used as a tag for list elements. It is a stylized
 * text item with a colored background and rounded corners.
 */
exports.ListItemTag = (props) => {
    const { label, style, styles = {}, theme: themeOverride, 
    // ignore unused vars so that we can do prop transferring to the root element
    /* eslint-disable @typescript-eslint/no-unused-vars */
    fontColor, backgroundColor, 
    /* eslint-enable @typescript-eslint/no-unused-vars */
    ...otherTextProps } = props;
    const theme = react_native_paper_1.useTheme(themeOverride);
    const fontScale = react_native_1.PixelRatio.getFontScale();
    const defaultStyles = listItemTagStyles(props, theme, fontScale);
    return (react_1.default.createElement(typography_1.Overline, Object.assign({ style: [defaultStyles.root, styles.root, style] }, otherTextProps), label));
};
exports.ListItemTag.displayName = 'ListItemTag';
