"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedProgressBar = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const useAlternateTheme_1 = require("./hooks/useAlternateTheme");
/**
 * ThemedProgressBar component
 *
 * This component is a wrapper around the React Native Paper [ProgressBar](https://callstack.github.io/react-native-paper/progress-bar.html)
 * component. It accepts all the same props as the RNP component. The wrapper simply performs some minor theme / style overrides
 * in order to make the component look the way we want for Brightlayer UI projects.
 */
exports.ThemedProgressBar = (props) => {
    const { theme: themeOverride, ...other } = props;
    const theme = useAlternateTheme_1.useAlternateTheme(themeOverride);
    return react_1.default.createElement(react_native_paper_1.ProgressBar, Object.assign({}, other, { theme: theme }));
};
