"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAlternateTheme = void 0;
const react_native_paper_1 = require("react-native-paper");
const deepmerge_1 = __importDefault(require("deepmerge"));
/**
 * useAlternateTheme hook
 *
 * This hook is used to set up the alternative theme for various components (mostly in dark mode). Some RNP components use colors
 * from the theme that we would prefer that they did not. For these components, we modify the theme to move the colors
 * we want into the variables that are being used by RNP (e.g., for primary colored buttons, we want to use the dark variation).
 *
 * @returns a partial theme that can be passed to the `theme` prop of a RNP component
 */
exports.useAlternateTheme = (themeOverride, extraLight, extraDark) => {
    const theme = react_native_paper_1.useTheme(themeOverride);
    const altDarkTheme = deepmerge_1.default.all([
        {
            colors: {
                primary: theme.colors?.primaryPalette?.dark || theme.colors.primary,
                accent: theme.colors?.accentPalette?.dark || theme.colors.accent,
                background: theme.colors.surface,
                notification: theme.colors?.accentPalette?.dark || theme.colors.notification,
            },
        },
        extraDark || {},
        themeOverride || {},
    ]);
    const altLightTheme = deepmerge_1.default.all([{}, extraLight || {}, themeOverride || {}]);
    return theme.dark ? altDarkTheme : altLightTheme;
};
